@@ -8,7 +8,7 @@ REQUIRED_AUTOMAKE_VERSION=1.9
 
 PKG_NAME="mate-common"
 
-(test -f $srcdir/configure.in) || {
+(test -f $srcdir/configure.ac) || {
     echo -n "**Error**: Directory "\`$srcdir\'" does not look like the"
     echo " top-level $PKG_NAME directory"
     exit 1
